@@ -3,9 +3,13 @@ available here as well to keep the number of imports to a minimum for most
 applications.
 """
 
+import os
+
 from .base import SquirroClient
 from .document_uploader import DocumentUploader
-from .exceptions import *
+from .exceptions import *  # noqa: F403
 from .item_uploader import ItemUploader
 
-__version__ = "3.6.4"
+# Note: This variable is matched in the `make publish-client` sed command to set a static version for a release.
+__SQUIRRO_VERSION__ = "3.11.0"
+__version__ = __SQUIRRO_VERSION__
