@@ -1,5 +1,4 @@
 import copy
-import json
 import logging
 import warnings
 
@@ -17,6 +16,7 @@ from .exceptions import (
 )
 from .topic import TopicApiMixin
 from .user import UserApiMixin
+from .util import _dumps, _loads
 
 log = logging.getLogger(__name__)
 # SQ-7983: lower the log level of retry module to give some feedback
@@ -96,7 +96,6 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
     """
 
     def __init__(self, client_id, client_secret, **kwargs):
-
         # assign authentication class state
         self.client_id = client_id
         self.client_secret = client_secret
@@ -127,7 +126,6 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         self.retry = copy.deepcopy(RETRY)
         for k, v in kwargs.items():
             if k.startswith("retry_"):
-
                 # `method_whitelist` has been deprecated
                 if k == "retry_method_whitelist":
                     k = "retry_allowed_methods"
@@ -224,7 +222,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         if self.tenant is not None:
             base["tenant"] = self.tenant
         if user_information is not None:
-            base["user_information"] = json.dumps(user_information)
+            base["user_information"] = _dumps(user_information)
 
         # walk through all possible authentication scenarios
         # - access token
@@ -285,7 +283,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         try:
             # decode the JSON response and store tokens
             if r.content:
-                res = json.loads(r.content)
+                res = _loads(r.content)
         except ValueError as ex:
             log.error("unable to decode JSON: %r", r.content)
             raise TransportError(r.status_code, ex)
@@ -370,7 +368,6 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
 
             # check for failed authorization
             if retry_count == 0 and res.status_code == 401:
-
                 # try to refresh the tokens, if that fails we return the
                 # previous response
                 successful = self._refresh_tokens()
@@ -440,7 +437,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         data = {}
         try:
             if res.content:
-                data = json.loads(res.content)
+                data = _loads(res.content)
         except ValueError as ex:
             log.error("unable to decode JSON: %r", res.content)
             raise TransportError(None, ex)
