@@ -14,7 +14,7 @@ log = logging.getLogger(__name__)
 TIMEOUT_SECS = 300
 
 
-class DocumentUploader(object):
+class DocumentUploader:
     """Document uploader class which simplifies the indexing of office
     documents. Default parameters are loaded from your home directories
     .squirrorc. See the documentation of [[ItemUploader]] for a complete
@@ -77,7 +77,6 @@ class DocumentUploader(object):
         timeout_secs=TIMEOUT_SECS,
         **kwargs
     ):
-
         # assemble steps_config configuration
         source_id = kwargs.pop("source_id", None)
         pipeline_workflow_id = kwargs.pop("pipeline_workflow_id", None)
