@@ -22,7 +22,7 @@ class SquirroError(Exception):
         ret = None
         if len(self.args) > 1:
             ret = self.args[1]
-        if not isinstance(ret, str) and not isinstance(ret, dict):
+        if ret and not isinstance(ret, str) and not isinstance(ret, dict):
             ret = str(ret)
         return ret
 
