@@ -12,7 +12,7 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
 
     def __init__(self, *args, **kwargs):
         """Constructor for a new platform Squirro client."""
-        super(PlatformSquirroClient, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # extract the supported callbacks
         # - on_refresh_token
@@ -39,9 +39,7 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
         """
 
         # call parent function
-        super(PlatformSquirroClient, self)._on_token_refresh(
-            access_token, refresh_token
-        )
+        super()._on_token_refresh(access_token, refresh_token)
 
         # safely invoke callback
         try:
@@ -61,7 +59,7 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
             kwargs = self._before_token_refresh()
 
         # call parent function
-        ret = super(PlatformSquirroClient, self)._refresh_tokens(**kwargs)
+        ret = super()._refresh_tokens(**kwargs)
         if ret:
             return ret
 
@@ -77,5 +75,5 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
             raise
 
         # call parent function again
-        ret = super(PlatformSquirroClient, self)._refresh_tokens(**kwargs)
+        ret = super()._refresh_tokens(**kwargs)
         return ret
