@@ -75,6 +75,8 @@ class ItemUploader:
         of a new data source.
     :param non_retry_list: List of status codes for which we don't want a
         retry/backoff logic. Defaults to `[200, 202, 401, 403, 400, 404]`.
+    :param priority_level: Priority level of the data source. Possible choices: ``low``,
+        ``normal``, ``high``.
 
         200, 202
             Successful codes.
@@ -143,6 +145,7 @@ class ItemUploader:
         dataloader_options=None,
         dataloader_plugin_options=None,
         non_retry_list=[200, 202, 400, 401, 403, 404],
+        priority_level=None,
         **kwargs,
     ):
         self.non_retry_list = non_retry_list
@@ -259,6 +262,7 @@ class ItemUploader:
                 pipeline_workflow_id=workflow["id"],
                 dataloader_options=dataloader_options,
                 dataloader_plugin_options=dataloader_plugin_options,
+                priority_level=priority_level,
             )
             log.info("New source created with id %r", source["id"])
 
@@ -456,6 +460,7 @@ class ItemUploader:
         pipeline_workflow_id,
         dataloader_options=None,
         dataloader_plugin_options=None,
+        priority_level=None,
     ):
         default_dataloader_options = {
             "project_id": self.project_id,
@@ -485,6 +490,7 @@ class ItemUploader:
             config=source_config,
             scheduling_options={"force_stop_scheduling": True},
             pipeline_workflow_id=pipeline_workflow_id,
+            priority=priority_level,
         )
         return res
 
