@@ -2,12 +2,11 @@
 List of all exposed Squirro-APIs.
 """
 
-import json
 import logging
 import sys
-from typing import Dict, Optional
+from typing import Any, Dict, List, Literal, Optional
 
-from ..util import deprecation
+from ..util import _dumps, deprecation
 from .communities import CommunitiesMixin
 from .community_subscription import CommunitySubscriptionsMixin
 from .community_types import CommunityTypesMixin
@@ -29,6 +28,7 @@ from .ml_publish import MLPublishMixin
 from .ml_sentence_splitter import MLSentenceSplitterMixin
 from .ml_template import MLTemplatesMixin
 from .ml_user_feedback import MLUserFeedbackMixin
+from .notes import NotesMixin
 from .objects import ObjectsMixin
 from .pipeline_sections import PipelineSectionsMixin
 from .pipeline_status import PipelineStatusMixin
@@ -205,14 +205,14 @@ class TopicApiBaseMixin:
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def query_for_you(
         self,
         project_id: str,
         query: Optional[str] = None,
-        query_context: Optional[Dict[str, Optional[str]]] = None,
+        query_context: Optional[Dict[str, Any]] = None,
         aggregations=None,
         start=None,
         count=None,
@@ -233,8 +233,6 @@ class TopicApiBaseMixin:
             - search only within last read items by the user
             - search only within top trending items on the project (tbd)
 
-        **Experimental - likely to be changed in the future!**
-
         :param kwargs: The endpoint supports the same arguments as the `query` endpoint (except pagination).
 
         :returns: Matching query items annoted with `item_read` metadata & sorted DESC by user-read-time:
@@ -251,7 +249,13 @@ class TopicApiBaseMixin:
             'items': [
                 {'id': 'z9CNx-NMK5ZwCGpg5FrqUw',
                 'title': 'Climate change accelerates',
-                'sources': [{'id': 'Y2zh9RFbTVqG2hBmuoATNQ', 'title': 'CSV'}],
+                'sources': [
+                    {
+                        'id': 'Y2zh9RFbTVqG2hBmuoATNQ',
+                        'title': 'CSV',
+                        'photo': '<path_to_access_datasource_picture>'
+                    }
+                ],
                 'item_read': {
                     'last_read_by_user': '2022-07-04T15:58:24',
                     'read_count_by_user': 3
@@ -290,18 +294,18 @@ class TopicApiBaseMixin:
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def query(
         self,
         project_id: str,
         query: Optional[str] = None,
-        query_context: Optional[Dict[str, Optional[str]]] = None,
+        query_context: Optional[Dict[str, Any]] = None,
         aggregations=None,
         start=None,
         count=None,
-        fields=None,
+        fields: Optional[List[str]] = None,
         highlight=None,
         next_params=None,
         created_before=None,
@@ -310,6 +314,7 @@ class TopicApiBaseMixin:
         encrypted_query=None,
         child_count=None,
         timing: bool = False,
+        explain: bool = False,
         **kwargs,
     ):
         """Returns items for the provided project.
@@ -325,6 +330,7 @@ class TopicApiBaseMixin:
 
                 - `searchbar_query` : Terms that user typed in a searchbar.
                 - `dashboard_filters` : Additional filter-queries provided via dashboard or widget configuration.
+                - `community_query` : Selected community in the Community 360 dashboard.
                 - `like` : Additional input to perform approximate search on.
                          For now `like` is considered to be a long string (e.g. paragraphs)
                 - `parsed` : The parsed, analysed and enriched representation of the `searchbar_query` (response of the configured `query-processing workflow <https://go.squirro.com/libnlp-query-processing>`_)
@@ -349,6 +355,12 @@ class TopicApiBaseMixin:
                 - `update_cache` if `False` the result won't be cached. Used
                   for non-interactive queries that iterate over a large number
                   of items. Defaults to `True`.
+                - `response_format`: Format of the response. Valid options are:
+                    - `document`: The response has a document-based structure.
+                    - `paragraph`: The response is structured as a collection of individual paragraphs.
+                - `search_scope`: Scope of the search. Valid options are:
+                    - `document`: Search is performed on the standard documents.
+                    - `paragraph`: Search is conducted using paragraphs.
 
         :param encrypted_query: Optional Encrypted query returned by
             `get_encrypted_query` method. This parameter overrides the `query`
@@ -362,6 +374,7 @@ class TopicApiBaseMixin:
         :param created_after: Restrict result set to items created after
             `created_after`.
         :param timing: Boolean, specifies if detailed execution time profiling is reported (`True`). Disabled by default (`False`). The reported timing profile consists of a call stack with important subroutine execution times measured in milliseconds [ms]. If enabled, the report is returned with key `timing_report`.
+        :param explain: If set to `True`, add explanation of the search to the result.
         :param kwargs: Additional query parameters. All keyword arguments are
             passed on verbatim to the API.
 
@@ -379,7 +392,12 @@ class TopicApiBaseMixin:
             {'count': 1,
              'items': [{'id': '7rjxIjg_gPjrfjTk3dsTTA',
                'title': "FDA Adviser: Vaccine To Be OK'd In Days, But 'Normal' May Not Return Until Next Fall",
-               'sources': [{'id': '4fp-1YiASwS-kfNEXYus_g', 'title': 'News Source'}]}],
+               'sources': [{
+                    'id': '4fp-1YiASwS-kfNEXYus_g',
+                    'title': 'News Source',
+                    'photo': '<path_to_access_datasource_picture>'
+                }]
+             }],
              'now': '2022-03-21T16:53:52',
              'eof': False,
              'total': 2254,
@@ -438,6 +456,7 @@ class TopicApiBaseMixin:
             "created_after": created_after,
             "encrypted_query": encrypted_query,
             "timing": "true" if timing else None,  # timing parameter expects a str
+            "explain": explain,
         }
         if "scroll" in kwargs:
             logging.warning(
@@ -445,17 +464,83 @@ class TopicApiBaseMixin:
                 "Use `scan` method to perform scrolling."
             )
             kwargs.pop("scroll")
-        if args.get("spellcheck") and isinstance(args["spellcheck"], dict):
+        if kwargs.get("spellcheck") and isinstance(kwargs["spellcheck"], dict):
             logging.warning(
                 "Using dictionary in the `spellcheck` parameter is deprecated. "
                 "Use the `bool` value instead that specifies whether to check the "
                 "spelling of the provided query."
             )
-            args["spellcheck"] = True
+            kwargs["spellcheck"] = True
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
+        return self._process_response(res)
+
+    def multi_query(
+        self,
+        project_id: str,
+        queries: List[Dict[str, Any]],
+        rank_method: Literal["rrf"] = "rrf",
+    ):
+        """
+        Perform multiple queries and combine the results based on provided parameters.
+
+        .. warning::
+            This is an experimental feature and can change/be removed between releases
+            without notice.
+
+        :param project_id: ID of the project.
+        :param queries: List of queries to perform. Each query is a dictionary
+            containing the same arguments as the `query` method.
+        :param rank_method: Method to rank collected items. Currently supported
+            methods: `rrf`.
+
+        :returns: List of combined items from multiple queries.
+
+        Example::
+
+            >>> client.multi_query(
+            ...    project_id="DSuNrcnlSc6x5SJZh02IyQ",
+            ...    queries=[
+            ...        {"query": "food"},
+            ...        {"query": "food or climate"},
+            ...     ],
+            ...     rank_method="rrf",
+            ... )
+
+            {
+                "results": [
+                    [
+                        {
+                            "id": "z9CNx-NMK5ZwCGpg5FrqUw",
+                            "title": "Food allergies",
+                        },
+                        {
+                            "id": "z9CNx-NMK5ZwCGpg5FrqUw",
+                            "title": "Food allergies",
+                        },
+                    ],
+                    [
+                        None,
+                        {
+                            "id": "DSuNrcnlSc6x5SJZh02IyQ",
+                            "title": "Climate change",
+                        },
+                    ],
+                ]
+            }
+
+        """
+        res = self._perform_request(
+            "post",
+            (
+                f"{self.topic_api_url}/{self.version}/{self.tenant}/projects"
+                f"/{project_id}/items/multi_query"
+            ),
+            data=_dumps({"queries": queries, "rank_method": rank_method}),
+            headers={"Content-Type": "application/json"},
+        )
         return self._process_response(res)
 
     def recommend(
@@ -533,7 +618,7 @@ class TopicApiBaseMixin:
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def recommendation_methods(self, project_id):
@@ -670,7 +755,7 @@ class TopicApiBaseMixin:
         data["count"] = count
         data["explanation_count"] = explanation_count
         data["method"] = method
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def recommend_facets_explore(
@@ -764,7 +849,7 @@ class TopicApiBaseMixin:
         data["feature_type"] = "facet"
         data["count"] = count
         data["method"] = method
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
 
         json_response = self._process_response(res)
         if json_response:
@@ -933,7 +1018,7 @@ class TopicApiBaseMixin:
         data["count"] = count
         data["explanation_count"] = explanation_count
         data["method"] = method
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def query_entities(
@@ -1061,7 +1146,7 @@ class TopicApiBaseMixin:
         }
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def recommend_entities_explore(
@@ -1150,7 +1235,7 @@ class TopicApiBaseMixin:
         data["feature_type"] = "entity"
         data["count"] = count
         data["method"] = method
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
 
         json_response = self._process_response(res)
         if json_response:
@@ -1211,7 +1296,7 @@ class TopicApiBaseMixin:
         self,
         project_id,
         query=None,
-        scroll="5m",
+        scroll="1m",
         preserve_order=False,
         preserve_scroll_order=False,
         count=1000,
@@ -1282,13 +1367,10 @@ class TopicApiBaseMixin:
         if options:
             assert "fold_near_duplicate" not in options
 
-        url = "%(ep)s/%(version)s/%(tenant)s" "/projects/%(project_id)s/items/query"
-        url = url % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = (
+            f"{self.topic_api_url}/{self.version}/{self.tenant}/"
+            f"projects/{project_id}/items/query"
+        )
 
         if preserve_order:
             logging.warning(
@@ -1314,18 +1396,33 @@ class TopicApiBaseMixin:
         data = {k: v for k, v in args.items() if v is not None}
 
         items = True
-        while items:
-            res = self._process_response(
-                self._perform_request(
-                    "post", url, data=json.dumps(data), headers=headers
+        res = None
+        try:
+            while items:
+                res = self._process_response(
+                    self._perform_request(
+                        "post", url, data=_dumps(data), headers=headers
+                    )
                 )
-            )
-            items = res.get("items", [])
-            yield from items
-            if not res.get("eof"):
-                data["next_params"] = res.get("next_params")
-            else:
-                break
+                items = res.get("items", [])
+                yield from items
+                if not res.get("eof"):
+                    data["next_params"] = res.get("next_params")
+                else:
+                    break
+        except GeneratorExit:
+            logging.warning("Scanning of items was interrupted")
+        except Exception as ex:
+            logging.exception(f"Could not process the response: {ex}")
+            raise
+        finally:
+            if res is not None:
+                scroll_id = res.get("next_params").get("scroll_id")
+                url = (
+                    f"{self.topic_api_url}/{self.version}/{self.tenant}/"
+                    f"projects/{project_id}/scan_artifacts/scroll_context/{scroll_id}"
+                )
+                res = self._perform_request("delete", url)
 
     def get_items(self, project_id, **kwargs):
         """Returns items for the provided project.
@@ -1408,13 +1505,11 @@ class TopicApiBaseMixin:
                        'item_score': 0.5,
                        'score': 0.56,
                        'sources': [{'id': 'oMNOQ-3rQo21q3UmaiaLHw',
-                                     'link': 'https://gdata.youtube.com/...',
-                                     'provider': 'feed',
-                                     'title': 'Uploads by mymemonic'},
+                                     'title': 'Uploads by mymemonic',
+                                     'photo': '<path_to_access_datasource_picture>'},
                                     {'id': 'H4nd0CasQQe_PMNDM0DnNA',
-                                     'link': None,
-                                     'provider': 'savedsearch',
-                                     'title': 'Squirro Alerts for "memonic"'}
+                                     'title': 'Squirro Alerts for "memonic"',
+                                     'photo': '<path_to_access_datasource_picture>'}
                                    ],
                        'starred': False,
                        'thumbler_url': '[long url]...jpg',
@@ -1436,17 +1531,18 @@ class TopicApiBaseMixin:
             "item_id": item_id,
         }
         if isinstance(kwargs.get("highlight_query"), dict):
-            kwargs["highlight_query"] = json.dumps("highlight_query")
+            kwargs["highlight_query"] = _dumps("highlight_query")
         res = self._perform_request("get", url, params=kwargs)
         return self._process_response(res)
 
-    def _build_item_update(self, star, read, keywords, entities):
+    def _build_item_update(self, star, read, keywords, entities, title: Optional[str]):
         """Builds an update for a single item.
 
         :param star: Starred flag for the item, either `True` or `False`.
         :param read: Read flag for the item, either `True` or `False`.
         :param keywords: Updates to the `keywords` of the item.
         :param entities: Updates to the `entities` of the item.
+        :param title: Updated title of the item.
         """
 
         # build item state
@@ -1456,7 +1552,7 @@ class TopicApiBaseMixin:
         if read is not None:
             state["read"] = read
 
-        data = {"state": state}
+        data: Dict[str, Any] = {"state": state}
 
         if keywords is not None:
             data["keywords"] = keywords
@@ -1464,6 +1560,9 @@ class TopicApiBaseMixin:
         if entities is not None:
             data["entities"] = entities
 
+        if title is not None:
+            data["title"] = title
+
         return data
 
     def modify_item(
@@ -1475,6 +1574,7 @@ class TopicApiBaseMixin:
         keywords=None,
         entities=None,
         force_cache_clear=None,
+        title: Optional[str] = None,
     ):
         """Updates the flags, entities, and/or keywords of an item.
 
@@ -1489,6 +1589,7 @@ class TopicApiBaseMixin:
         :param entities: Updates to the `entities` of the item.
         :param force_cache_clear: Deprecated. This is the default behavior now.
             Force all relevant caches to be cleared
+        :param title: Updated title of the item.
 
         Example::
 
@@ -1519,11 +1620,11 @@ class TopicApiBaseMixin:
             "item_id": item_id,
         }
 
-        data = self._build_item_update(star, read, keywords, entities)
+        data = self._build_item_update(star, read, keywords, entities, title)
 
         headers = {"Content-Type": "application/json"}
 
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         self._process_response(res, [204])
 
     def modify_items(
@@ -1608,8 +1709,9 @@ class TopicApiBaseMixin:
                 read = item.get("read")
                 keywords = item.get("keywords")
                 entities = item.get("entities")
+                title = item.get("title")
 
-                update = self._build_item_update(star, read, keywords, entities)
+                update = self._build_item_update(star, read, keywords, entities, title)
 
                 if not item_id:
                     raise ValueError("Missing field `id` %r" % (item))
@@ -1619,9 +1721,7 @@ class TopicApiBaseMixin:
 
             headers = {"Content-Type": "application/json"}
 
-            res = self._perform_request(
-                "put", url, data=json.dumps(data), headers=headers
-            )
+            res = self._perform_request("put", url, data=_dumps(data), headers=headers)
             self._process_response(res, [204])
 
     def delete_item(self, project_id, item_id):
@@ -1687,16 +1787,19 @@ class TopicApiBaseMixin:
 
             - `template_params` dict containing the query template parameters
             - `select_suggesters` (optional) list containing suggesters to be used.
+            - `select_facets` (optional) list containing facets to be used. Skip this setting or use `all` to match on all visible facets.
 
             If no suggesters are selected, all suggesters are executed by default.
             Available suggesters:
 
             - "facet_value": Complete on facet-values that have "autocomplete" enabled (Exact Search)
+            - "facet_value_lenient": Complete on facet-values that are "analyzed" and "visible" (Lenient exact search, ignores order. All tokens within the searchbar_query are matched as prefixes)
             - "facet_name: Help to find the correct facet
-            - "content_phrase": Complete on key-phrases + item-title (Fuzzy Search) added via NLP-Tagger
+            - "content_phrase": Complete on key-phrases (Fuzzy Search) added via NLP-Tagger
             - "saved_search": Complete on queries saved by the user
             - "popular_query": Complete on popular queries on the project, filtered by user_id (optional)
             - "search_history": Triggered only to pre-populate and show default-suggestions.
+            - "title": Complete on document title
               Returns last-N searches, filtered by project_id and user_id.
 
         :param filter_query: Squirro query to limit the typeahead suggestions.
@@ -1729,7 +1832,7 @@ class TopicApiBaseMixin:
         Example::
 
             # Autocomplete on one specific suggester like `content_phrase`
-            # - The "content_phrase" suggester completes on key-phrases and item titles added by
+            # - The "content_phrase" suggester completes on key-phrases added by
             #  `NLP-Tagger <https://squirro.atlassian.net/wiki/spaces/DOC/pages/2396061784/Content-based+Typeahead>`__
             # - Autocompletion supports in-order phrase & fuzzy string matching
             # - Highlighted tokens are returned as <b> html tags
@@ -1772,7 +1875,7 @@ class TopicApiBaseMixin:
         params["filter_query"] = filter_query
 
         if options:
-            params["options"] = json.dumps(options)
+            params["options"] = _dumps(options)
 
         # issue request
         res = self._perform_request("get", url, params=params)
@@ -1818,7 +1921,7 @@ class TopicApiBaseMixin:
         }
 
         headers = {"Content-Type": "application/json"}
-        data = json.dumps(params)
+        data = _dumps(params)
         res = self._perform_request("post", url, headers=headers, data=data)
         # This errors out if permissions are missing
         self._process_response(res, [204])
@@ -1865,5 +1968,6 @@ class TopicApiMixin(
     MLUserFeedbackMixin,
     MLSentenceSplitterMixin,
     SmartAnswersMixin,
+    NotesMixin,
 ):
     pass
