@@ -1,6 +1,7 @@
-import json
 from typing import Any, Optional, Union
 
+from ..util import _dumps
+
 
 class ConfigurationMixin:
     def get_server_configuration(self):
@@ -47,7 +48,9 @@ class ConfigurationMixin:
                         'default_value': True,
                         'type': 'boolean',
                         'delete': 'reset',
-                        'help': 'Whether new users can be created on this sytemn.'
+                        'help': 'Whether new users can be created on this sytemn.',
+                        'schema': None,
+                        'schema_model': None
                     },
                 },
                 # …
@@ -55,7 +58,8 @@ class ConfigurationMixin:
         """
         # Build URL
         url = "{ep}/v0/{tenant}/configuration".format(
-            ep=self.topic_api_url, tenant=self.tenant,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
         )
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -108,18 +112,20 @@ class ConfigurationMixin:
                 'default_value': True,
                 'type': 'boolean',
                 'help': 'Whether new users can be created on this system.',
-                'delete': 'reset'
+                'delete': 'reset',
+                'schema': None,
+                'schema_model': None
             }
         """
         # Build URL
         url = "{ep}/v0/{tenant}/configuration/{key}".format(
-            ep=self.topic_api_url, tenant=self.tenant, key=key,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            key=key,
         )
         headers = {"Content-Type": "application/json"}
         post_data = {"value": value, "type": type}
-        res = self._perform_request(
-            "put", url, data=json.dumps(post_data), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(post_data), headers=headers)
         return self._process_response(res, [200])
 
     def delete_server_configuration(self, key):
@@ -145,6 +151,8 @@ class ConfigurationMixin:
                 'type': 'boolean',
                 'help': 'Whether custom index locators can be defined on Squirro projects.',
                 'delete': 'noop',
+                'schema': None,
+                'schema_model': None
             }
 
             >>> c.set_server_configuration(key='user.create', value=False)
@@ -156,22 +164,29 @@ class ConfigurationMixin:
                 'default_value': True,
                 'type': 'boolean',
                 'help': 'Whether new users can be created on this system.',
-                'delete': 'reset'
+                'delete': 'reset',
+                'schema': None,
+                'schema_model': None
             }
         """
 
         # Build URL
         url = "{ep}/v0/{tenant}/configuration/{key}".format(
-            ep=self.topic_api_url, tenant=self.tenant, key=key,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            key=key,
         )
         res = self._perform_request("delete", url)
         return self._process_response(res, [200, 204])
 
-    def get_project_configuration(self, project_id: str):
+    def get_project_configuration(
+        self, project_id: str, exclude_read_only_and_license: bool = False
+    ):
         """
         Return all configuration service values from the project namespace.
 
         :param project_id: Project ID.
+        :param exclude_read_only_and_license: Whether to exclude read-only and license settings from the response. Defaults to `False`.
 
         :return: Returns a dictionary with the returned data and configuration.
                 The relevant keys in the returned dictionary are:
@@ -214,7 +229,9 @@ class ConfigurationMixin:
                         'default_value': 'user',
                         'type': 'string',
                         'delete': 'reset',
-                        'help': 'A scope for popular queries (user/project).'
+                        'help': 'A scope for popular queries (user/project).',
+                        'schema': None,
+                        'schema_model': None
                     },
                 },
                 # …
@@ -223,7 +240,8 @@ class ConfigurationMixin:
         url = (
             f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}/configuration"
         )
-        res = self._perform_request("get", url)
+        params = {"exclude_read_only_and_license": exclude_read_only_and_license}
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res)
 
     def set_project_configuration(
@@ -278,15 +296,15 @@ class ConfigurationMixin:
                 'default_value': 'user',
                 'type': 'string',
                 'help': 'A scope for popular queries (user/project).',
-                'delete': 'reset'
+                'delete': 'reset',
+                'schema': None,
+                'schema_model': None
             }
         """
         url = f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}/configuration/{key}"
         headers = {"Content-Type": "application/json"}
         post_data = {"value": value, "type": type}
-        res = self._perform_request(
-            "put", url, data=json.dumps(post_data), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(post_data), headers=headers)
         return self._process_response(res, [200])
 
     def delete_project_configuration(self, project_id: str, key: str):
@@ -315,6 +333,8 @@ class ConfigurationMixin:
                 'type': 'string',
                 'help': 'A scope for popular queries (user/project).',
                 'delete': 'noop',
+                'schema': None,
+                'schema_model': None
             }
         """
         url = f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}/configuration/{key}"
@@ -344,6 +364,6 @@ class ConfigurationMixin:
         headers = {"Content-Type": "application/json"}
         post_data = {"value": value}
         res = self._perform_request(
-            "post", url, data=json.dumps(post_data), headers=headers
+            "post", url, data=_dumps(post_data), headers=headers
         )
         return self._process_response(res)
