@@ -1,12 +1,11 @@
-import json
 import logging
 
-from squirro_client.util import deprecation
+from ..util import _dumps, deprecation
 
 log = logging.getLogger(__name__)
 
 
-class DashboardsMixin(object):
+class DashboardsMixin:
     def get_dashboards(self, project_id):
         """Return all dashboard for the given project.
 
@@ -29,11 +28,11 @@ class DashboardsMixin(object):
                             u'title': u'Search Results',
                             u'type': u'Search'}]}]
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/dashboards".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -96,6 +95,9 @@ class DashboardsMixin(object):
         default_store=None,
         transparent=None,
         layout=None,
+        searchable=None,
+        visible=None,
+        communityWizard=None,
     ):
         """Create a new dashboard.
 
@@ -130,6 +132,9 @@ class DashboardsMixin(object):
         :param transparent: Boolean, whether the dashboard uses a transparent
             background or not
         :param layout: Dict, Dashboard layout configuration
+        :param searchable: Boolean, whether the dashboard is searchable or not
+        :param visible: Boolean, whether the dashboard is visible or not
+        :param communityWizard: Boolean, whether the dashboard uses the communityWizard
 
         :returns: A list of dashboard dictionaries.
 
@@ -292,7 +297,9 @@ class DashboardsMixin(object):
                     u'theme_id': u'ofVfiQ-uRWSZeGFZspH9nQ',
                     u'title': u'foo',
                     u'type': u'dashboard',
-                    u'layout': {}
+                    u'layout': {},
+                    u'searchable': u'false',
+                    u'visible': u'true',
                 }
         """
         if mobileSections:
@@ -302,11 +309,11 @@ class DashboardsMixin(object):
             msg = "Sections are deprecated please use panels instead"
             deprecation(msg)
 
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/dashboards".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         data = {
             "title": title,
             "search": search,
@@ -317,6 +324,9 @@ class DashboardsMixin(object):
             "loaders": loaders,
             "transparent": transparent,
             "layout": layout,
+            "searchable": searchable,
+            "visible": visible,
+            "communityWizard": communityWizard,
         }
         if dashboard_id:
             data["dashboard_id"] = dashboard_id
@@ -337,7 +347,7 @@ class DashboardsMixin(object):
             data["default_store"] = default_store
 
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def modify_dashboard(
@@ -365,6 +375,9 @@ class DashboardsMixin(object):
         role=None,
         transparent=None,
         layout=None,
+        searchable=None,
+        visible=None,
+        communityWizard=None,
     ):
         """Update a dashboard.
 
@@ -398,6 +411,9 @@ class DashboardsMixin(object):
         :param transparent: Boolean, whether the dashboard uses a transparent
             background or not
         :param layout: Dict, Dashboard layout configuration
+        :param searchable: Boolean, whether the dashboard is searchable or not
+        :param visible: Boolean, whether the dashboard is visible or not
+        :param communityWizard: Boolean, whether the dashboard opens the Community Wizard
 
         :returns: A dictionary of the updated dashboard.
 
@@ -446,6 +462,9 @@ class DashboardsMixin(object):
             "default_store": default_store,
             "transparent": transparent,
             "layout": layout,
+            "searchable": searchable,
+            "visible": visible,
+            "communityWizard": communityWizard,
         }
 
         if master is not None:
@@ -458,9 +477,7 @@ class DashboardsMixin(object):
             if value is not None:
                 post_data[key] = value
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request(
-            "put", url, data=json.dumps(post_data), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(post_data), headers=headers)
         return self._process_response(res)
 
     def move_dashboard(self, project_id, dashboard_id, after):
@@ -491,7 +508,7 @@ class DashboardsMixin(object):
         }
         headers = {"Content-Type": "application/json"}
         res = self._perform_request(
-            "post", url, data=json.dumps({"after": after}), headers=headers
+            "post", url, data=_dumps({"after": after}), headers=headers
         )
         return self._process_response(res, [204])
 
@@ -620,7 +637,7 @@ class DashboardsMixin(object):
         }
         headers = {"Content-Type": "application/json"}
         res = self._perform_request(
-            "post", url, data=json.dumps(permissions_list), headers=headers
+            "post", url, data=_dumps(permissions_list), headers=headers
         )
         return self._process_response(res)
 
