@@ -1,4 +1,4 @@
-import json
+from ..util import _dumps
 
 
 class EmailTemplatesMixin:
@@ -45,7 +45,7 @@ class EmailTemplatesMixin:
             name=template_name,
         )
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [200])
 
     def send_sample_email(self, template_name, email, data):
@@ -64,5 +64,5 @@ class EmailTemplatesMixin:
             email=email,
         )
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("post", url, headers=headers, data=json.dumps(data))
+        res = self._perform_request("post", url, headers=headers, data=_dumps(data))
         return self._process_response(res, [200])
