@@ -1,10 +1,11 @@
-import json
 import urllib.error
 import urllib.parse
 import urllib.request
 
+from ..util import _dumps
 
-class EnrichmentsMixin(object):
+
+class EnrichmentsMixin:
     def create_enrichment(self, project_id, type, name, config, before=None):
         """Create a new enrichment on the project.
 
@@ -35,13 +36,13 @@ class EnrichmentsMixin(object):
         data = {"type": type, "name": name, "config": config}
         if before:
             data["before"] = before
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/enrichments" % {
-            "ep": self.topic_api_url,
-            "project_id": project_id,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/enrichments".format(
+            ep=self.topic_api_url,
+            project_id=project_id,
+            tenant=self.tenant,
+        )
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def get_enrichments(self, project_id, type=None):
@@ -62,11 +63,11 @@ class EnrichmentsMixin(object):
                 u'id': u'pipelet-rTBoGNl6S4aG4TDkBoN6xQ'
             }]
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/enrichments" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/enrichments".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         # build params
         params = {}
@@ -171,5 +172,5 @@ class EnrichmentsMixin(object):
             "enrichment_id": urllib.parse.quote_plus(enrichment_id),
         }
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
