@@ -1,7 +1,7 @@
-import json
+from ..util import _dumps
 
 
-class ProjectGuideFilesMixin(object):
+class ProjectGuideFilesMixin:
     def new_guide_file(self, project_id, guide_content):
         """Creates a new Project Guide file.
 
@@ -27,7 +27,7 @@ class ProjectGuideFilesMixin(object):
             guide_content = guide_content.decode()
 
         data = {"data": {"guide_content": guide_content}}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def get_guide_file(self, project_id):
