@@ -1,12 +1,14 @@
 import base64
 import io
-import json
 import logging
 import re
-import tarfile
 import time
 from typing import Optional
 
+import tarsafe
+
+from ..util import _dumps
+
 log = logging.getLogger(__name__)
 
 
@@ -21,7 +23,7 @@ class MachineLearningMixin:
         if ml_models:
             try:
                 with io.BytesIO() as binary_data:
-                    with tarfile.open(
+                    with tarsafe.open(
                         fileobj=binary_data, mode="w|gz", dereference=dereference
                     ) as tar:
                         tar.add(ml_models, arcname=".", recursive=True)
@@ -70,7 +72,7 @@ class MachineLearningMixin:
         self._inject_ml_models(ml_workflow, ml_models)
 
         res = self._perform_request(
-            "post", url, data=json.dumps(ml_workflow), headers=headers
+            "post", url, data=_dumps(ml_workflow), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -174,7 +176,7 @@ class MachineLearningMixin:
         url = "/".join([base_url, ml_workflow_id])
         url = url.format(self.topic_api_url, self.tenant, project_id)
         res = self._perform_request(
-            "put", url, data=json.dumps(ml_workflow_update), headers=headers
+            "put", url, data=_dumps(ml_workflow_update), headers=headers
         )
         return self._process_response(res, [204])
 
@@ -200,6 +202,11 @@ class MachineLearningMixin:
         :param project_id: Id of the Squirro project.
         :param ml_workflow_id: Id of the Machine Learning workflow.
         :param data: Data to run through Machine Learning workflow.
+            -`response_format`: Format of the response. Valid options are:
+                - `standard`: The default format of the response. Fields returned
+                by the Machine Learning workflow are wrapped into a list.
+                - `plain`: Fields returned from the Machine Learning workflow
+                are returned as they are, without wrapping.
         :param asynchronous: Whether or not to run Machine Learning workflow
             asynchronously (recommended for large data batches).
         """
@@ -213,7 +220,7 @@ class MachineLearningMixin:
         url = "/".join([base_url, ml_workflow_id])
         url = url.format(self.topic_api_url, self.tenant, project_id)
         res = self._perform_request(
-            "post", url, data=json.dumps(data), headers=headers, params=params
+            "post", url, data=_dumps(data), headers=headers, params=params
         )
         res = self._process_response(res)
 
@@ -259,7 +266,7 @@ class MachineLearningMixin:
         res = self._perform_request(
             "post",
             url,
-            data=json.dumps(
+            data=_dumps(
                 {
                     "name": name,
                     "type": type,
@@ -298,7 +305,7 @@ class MachineLearningMixin:
         data = {"type": type, "scheduling_options": scheduling_options}
         url = "/".join([base_url, ml_workflow_id, "jobs"])
         url = url.format(self.topic_api_url, self.tenant, project_id)
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def get_machinelearning_jobs(
