@@ -1,6 +1,7 @@
-import json
 import logging
 
+from ..util import _dumps
+
 log = logging.getLogger(__name__)
 
 
@@ -10,8 +11,7 @@ class ExecutionError(Exception):
     pass
 
 
-class MLCandidateSetMixin(object):
-
+class MLCandidateSetMixin:
     #
     #  ML Candidate Set (CS)
     #
@@ -20,11 +20,11 @@ class MLCandidateSetMixin(object):
 
         :param project_id: Id of the Squirro project.
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/candidate_set" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/candidate_set".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         headers = {"Content-Type": "application/json"}
         res = self._perform_request("get", url, headers=headers)
         return self._process_response(res)
@@ -35,12 +35,12 @@ class MLCandidateSetMixin(object):
         :param project_id: Id of the Squirro project.
         :param candidate_set_id: id of the candidate set.
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/candidate_set/%(cs_id)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-            "cs_id": candidate_set_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/candidate_set/{cs_id}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+            cs_id=candidate_set_id,
+        )
         headers = {"Content-Type": "application/json"}
 
         res = self._perform_request("get", url, headers=headers)
@@ -55,16 +55,16 @@ class MLCandidateSetMixin(object):
 
         """
 
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/candidate_set" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/candidate_set".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         headers = {"Content-Type": "application/json"}
         cs_params = {"name": name, "query": query}
 
         res = self._perform_request(
-            "post", url, data=json.dumps(cs_params), headers=headers
+            "post", url, data=_dumps(cs_params), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -76,15 +76,15 @@ class MLCandidateSetMixin(object):
         :param name: Name of Candidate Set.
         :param query: candidate set query to be sobstitute.
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/candidate_set/%(cs_id)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-            "cs_id": candidate_set_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/candidate_set/{cs_id}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+            cs_id=candidate_set_id,
+        )
         headers = {"Content-Type": "application/json"}
-        if not query:
-            query - "*"
+        if query is None:
+            query = ""
 
         cs_update = {}
 
@@ -92,9 +92,7 @@ class MLCandidateSetMixin(object):
         cs_update["name"] = name
         cs_update["query"] = query
 
-        res = self._perform_request(
-            "put", url, data=json.dumps(cs_update), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(cs_update), headers=headers)
         return self._process_response(res, [204])
 
     def delete_candidate_set(self, project_id, candidate_set_id):
@@ -103,12 +101,12 @@ class MLCandidateSetMixin(object):
         :param project_id: Id of the Squirro project.
         :param candidate_set_id: Id of the Candidate Set.
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/candidate_set/%(cs_id)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-            "cs_id": candidate_set_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/candidate_set/{cs_id}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+            cs_id=candidate_set_id,
+        )
         headers = {"Content-Type": "application/json"}
         res = self._perform_request("delete", url, headers=headers)
         return self._process_response(res, [204])
