@@ -1,7 +1,8 @@
 import datetime
-import json
 import logging
 
+from ..util import _dumps
+
 log = logging.getLogger(__name__)
 
 
@@ -12,7 +13,6 @@ class ExecutionError(Exception):
 
 
 class MLGroundTruthMixin:
-
     #
     #  ML Groundtruth (GT)
     #
@@ -34,6 +34,23 @@ class MLGroundTruthMixin:
 
         :param project_id: Id of the Squirro project.
         :param groundtruth_id: Id of the GroundTruth
+
+        **Examples**
+
+        *Get a single groundtruth*::
+
+            >>> client.get_groundtruth(
+                        project_id="DSuNrcnlSc6x5SJZh02IyQ",
+                        groundtruth_id="n57sJlpcTLy4_XxdvHvx5g")
+            {'bulk_labeling_status': 'no bulk labelings',
+            'config': {'candidatesets': [], 'labels': ['yes', 'no']},
+            'created_at': '1996-03-13T00:00:00',
+            'id': 'n57sJlpcTLy4_XxdvHvx5g',
+            'modified_at': '2015-06-09T00:00:00',
+            'name': 'Commercial final fly share white focus voice.',
+            'project_id': 'DSuNrcnlSc6x5SJZh02IyQ',
+            'bulk_labeling_status': 'no bulk labelings'
+            'rules': {}}
         """
         base_url = "{}/v0/{}/projects/{}/groundtruths/{}"
         headers = {"Content-Type": "application/json"}
@@ -60,7 +77,7 @@ class MLGroundTruthMixin:
         groundtruth_params = {"name": name, "config": config}
 
         res = self._perform_request(
-            "post", url, data=json.dumps(groundtruth_params), headers=headers
+            "post", url, data=_dumps(groundtruth_params), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -84,7 +101,7 @@ class MLGroundTruthMixin:
 
         url = url.format(self.topic_api_url, self.tenant, project_id, groundtruth_id)
         res = self._perform_request(
-            "put", url, data=json.dumps(groundtruth_update), headers=headers
+            "put", url, data=_dumps(groundtruth_update), headers=headers
         )
         return self._process_response(res, [204])
 
@@ -116,7 +133,7 @@ class MLGroundTruthMixin:
         count=None,
         start=None,
     ):
-        """Return the labeled extract of a ground truth for a project in a list.
+        """Return the labeled extract of a ground truth for a project in a list. Note: to avoid timeout issues in large ground truths, use `get_groundtruth_labels_batched` instead.
 
         :param project_id: Id of the Squirro project.
         :param groundtruth_id: Id of the GroundTruth
@@ -144,6 +161,66 @@ class MLGroundTruthMixin:
         res = self._perform_request("get", url, headers=headers, params=data)
         return self._process_response(res)
 
+    def get_groundtruth_labels_batched(
+        self,
+        project_id: str,
+        groundtruth_id: str,
+        batch_size=1000,
+        temporal_version=None,
+    ):
+        """
+        Returns a generator that goes through all the valid labeled extracts from the provided groundtruth. The generator is only valid for a short period of time, as it uses Elasticsearch's PIT API under the hood. It is preferable to use this method instead of `get_groundtruth_labels` when the number of labels is large, as it avoids timeout issues.
+
+        Args:
+            project_id (str): The ID of the project.
+            groundtruth_id (str): The ID of the groundtruth.
+            batch_size (int, optional): The size of the batch requested to the API. Defaults to 1000. If time out issues are encountered, try to reduce this value.
+            temporal_version (str, optional): The datetime string corresponding to the Ground Truth temporal version. Defaults to None.
+
+        Yields:
+            dict: A dictionary containing information about a labeled extract, including the extract text, keywords, item ID, etc.
+        """
+        headers = {"Content-Type": "application/json"}
+        data = {
+            "batch_size": batch_size,
+            "temporal_version": temporal_version,
+        }
+
+        url = f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}/groundtruths/{groundtruth_id}/labels_batch"
+
+        labels = True
+        res = None
+        try:
+            while labels:
+                res = self._process_response(
+                    self._perform_request(
+                        "post", url, data=_dumps(data), headers=headers
+                    )
+                )
+
+                res = res.get("groundtruth_labels", {})
+
+                labels = res.get("labels", [])
+                yield from labels
+                if not res.get("eof"):
+                    data["pit_id"] = res["next_params"]["pit_id"]
+                    data["search_after"] = res["next_params"]["search_after"]
+                else:
+                    break
+        except GeneratorExit:
+            logging.warning("Scanning of items was interrupted")
+        except Exception as ex:
+            logging.exception(f"Could not process the response: {ex}")
+            raise
+        finally:
+            if res is not None:
+                pit_id = res.get("next_params").get("pit_id")
+                url = (
+                    f"{self.topic_api_url}/{self.version}/{self.tenant}/"
+                    f"projects/{project_id}/scan_artifacts/pit_context/{pit_id}"
+                )
+                res = self._perform_request("delete", url)
+
     def get_groundtruth_label(self, project_id, groundtruth_id, label_id):
         """Get a single labeled extract from a Ground Truth.
 
@@ -178,7 +255,7 @@ class MLGroundTruthMixin:
         label_params = {"label": label}
 
         res = self._perform_request(
-            "post", url, data=json.dumps(label_params), headers=headers
+            "post", url, data=_dumps(label_params), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -200,9 +277,7 @@ class MLGroundTruthMixin:
 
         params = {"labels": labels}
 
-        res = self._perform_request(
-            "post", url, data=json.dumps(params), headers=headers
-        )
+        res = self._perform_request("post", url, data=_dumps(params), headers=headers)
         return self._process_response(res, [201])
 
     def modify_groundtruth_label(
@@ -224,7 +299,7 @@ class MLGroundTruthMixin:
         url = "/".join([base_url, label_id])
         url = url.format(self.topic_api_url, self.tenant, project_id, groundtruth_id)
         res = self._perform_request(
-            "put", url, data=json.dumps(label_update), headers=headers
+            "put", url, data=_dumps(label_update), headers=headers
         )
         return self._process_response(res, [200, 201])
 
@@ -295,7 +370,7 @@ class MLGroundTruthMixin:
         rule_params = {"rule": rule}
 
         res = self._perform_request(
-            "post", url, data=json.dumps(rule_params), headers=headers
+            "post", url, data=_dumps(rule_params), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -315,7 +390,7 @@ class MLGroundTruthMixin:
         url = "/".join([base_url, rule_id])
         url = url.format(self.topic_api_url, self.tenant, project_id, groundtruth_id)
         res = self._perform_request(
-            "put", url, data=json.dumps(rule_update), headers=headers
+            "put", url, data=_dumps(rule_update), headers=headers
         )
         return self._process_response(res, [204])
 
@@ -345,7 +420,8 @@ class MLGroundTruthMixin:
         temporal_version=None,
         label=None,
         labelled_filter=None,
-        **kwargs
+        highlight_filter=False,
+        **kwargs,
     ):
         """Returns items for the provided project enriched with Ground Truth data.
 
@@ -355,6 +431,7 @@ class MLGroundTruthMixin:
         :param temporal_version: temporal version of the Ground Truth
         :param label: label to filter Ground Truth by
         :param labelled_filter: filter if all items, only the already labelled or only the unlabelled items should get returned (accepted values:'all','labelled' and 'not_labelled')
+        :param highlight_filter : filter if only the highlighted items should get returned
         :param kwargs: Additional query parameters. All keyword arguments are
                        passed on verbatim to the API.
         :return:
@@ -366,6 +443,7 @@ class MLGroundTruthMixin:
             "temporal_version": temporal_version,
             "label": label,
             "labelled_filter": labelled_filter,
+            "highlight_filter": highlight_filter,
         }
         data.update(**kwargs)
         url = base_url.format(
@@ -400,7 +478,7 @@ class MLGroundTruthMixin:
         base_url = "{}/v0/{}/projects/{}/groundtruths/{}/items/{}"
         headers = {"Content-Type": "application/json"}
 
-        data = json.dumps(
+        data = _dumps(
             {
                 "data": {
                     "highlight_query": highlight_query,
