@@ -1,5 +1,7 @@
-import json
 import logging
+from typing import List, Optional
+
+from ..util import _dumps
 
 log = logging.getLogger(__name__)
 
@@ -11,7 +13,6 @@ class ExecutionError(Exception):
 
 
 class MLModelsMixin:
-
     #
     #  ML Model
     #
@@ -84,7 +85,7 @@ class MLModelsMixin:
         }
 
         res = self._perform_request(
-            "post", url, data=json.dumps(model_params), headers=headers
+            "post", url, data=_dumps(model_params), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -127,7 +128,7 @@ class MLModelsMixin:
             "is_incomplete": is_incomplete,
         }
         res = self._perform_request(
-            "put", url, data=json.dumps(model_params), headers=headers
+            "put", url, data=_dumps(model_params), headers=headers
         )
         return self._process_response(res, [204])
 
@@ -147,3 +148,70 @@ class MLModelsMixin:
         headers = {"Content-Type": "application/json"}
         res = self._perform_request("delete", url, headers=headers)
         return self._process_response(res, [204])
+
+    def get_bulk_labeling(
+        self,
+        project_id,
+        groundtruth_id,
+        ml_workflow_fields: Optional[List[str]] = None,
+        ml_job_fields: Optional[List[str]] = None,
+        job_count: Optional[int] = None,
+    ):
+        """Get new bulk labeling status.
+
+        :param project_id: Id of the Squirro project.
+        :param groundtruth_id: id of the grountruth.
+        :param ml_workflow_fields: list of fields of ML workflows
+        :param ml_job_fields: list of fields of ML jobs
+        """
+
+        url = "{ep}/v0/{tenant}/projects/{project_id}/bulk_labeling/{groundtruth_id}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+            groundtruth_id=groundtruth_id,
+        )
+        headers = {"Content-Type": "application/json"}
+
+        params = {
+            "ml_workflow_fields": ml_workflow_fields,
+            "ml_job_fields": ml_job_fields,
+            "job_count": job_count,
+        }
+
+        res = self._perform_request("get", url, data=_dumps(params), headers=headers)
+        return self._process_response(res, [200])
+
+    def new_bulk_labeling(
+        self,
+        project_id,
+        groundtruth_id,
+        name,
+        template_id,
+        template_params=None,
+    ):
+        """Create new bulk labeling.
+
+        :param project_id: Id of the Squirro project.
+        :param groundtruth_id: id of the grountruth.
+        :param name: Name of the ML Model.
+        :param template_id: template do be used.
+        :param template_params: parameters to initialize the template.
+        """
+
+        url = "{ep}/v0/{tenant}/projects/{project_id}/bulk_labeling/{groundtruth_id}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+            groundtruth_id=groundtruth_id,
+        )
+        headers = {"Content-Type": "application/json"}
+
+        params = {
+            "name": name,
+            "template_id": template_id,
+            "template_params": template_params,
+        }
+
+        res = self._perform_request("post", url, data=_dumps(params), headers=headers)
+        return self._process_response(res, [201])
