@@ -9,8 +9,7 @@ class ExecutionError(Exception):
     pass
 
 
-class MLSentenceSplitterMixin(object):
-
+class MLSentenceSplitterMixin:
     #
     #  ML Sentence Splitter
     #
@@ -19,11 +18,11 @@ class MLSentenceSplitterMixin(object):
 
         :param project_id: Id of the Squirro project.
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/ml_sentence_splitter" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/ml_sentence_splitter".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         headers = {"Content-Type": "application/json"}
         res = self._perform_request("get", url, headers=headers)
