@@ -1,4 +1,4 @@
-import json
+from ..util import _dumps
 
 
 class PipelineSectionsMixin:
@@ -11,16 +11,14 @@ class PipelineSectionsMixin:
         """
         headers = {"Content-Type": "application/json"}
 
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/pipeline_sections" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/pipeline_sections".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         data_dict = dict(omit_steps=omit_steps)
 
-        res = self._perform_request(
-            "get", url, data=json.dumps(data_dict), headers=headers
-        )
+        res = self._perform_request("get", url, data=_dumps(data_dict), headers=headers)
 
         return self._process_response(res)
