@@ -1,4 +1,4 @@
-import json
+from ..util import _dumps
 
 
 class PipelineStatusMixin:
@@ -44,7 +44,7 @@ class PipelineStatusMixin:
         action_config["action"] = action
 
         res = self._perform_request(
-            "post", url, data=json.dumps(action_config), headers=headers
+            "post", url, data=_dumps(action_config), headers=headers
         )
 
         return self._process_response(res)
