@@ -1,9 +1,9 @@
-import json
 from typing import List, Optional, Union
 
+from ..util import _dumps
+
 
 class PipelineWorkflowMixin:
-
     #
     # Pipeline Workflows
     #
@@ -56,9 +56,7 @@ class PipelineWorkflowMixin:
 
         data_dict = dict(omit_steps=omit_steps, omit_sources=omit_sources)
 
-        res = self._perform_request(
-            "get", url, data=json.dumps(data_dict), headers=headers
-        )
+        res = self._perform_request("get", url, data=_dumps(data_dict), headers=headers)
 
         return self._process_response(res)
 
@@ -111,9 +109,7 @@ class PipelineWorkflowMixin:
 
         data_dict = dict(omit_steps=omit_steps, omit_sources=omit_sources)
 
-        res = self._perform_request(
-            "get", url, data=json.dumps(data_dict), headers=headers
-        )
+        res = self._perform_request("get", url, data=_dumps(data_dict), headers=headers)
 
         return self._process_response(res)
 
@@ -155,7 +151,7 @@ class PipelineWorkflowMixin:
         }
 
         res = self._perform_request(
-            "post", url, data=json.dumps(data_dict), headers=headers
+            "post", url, data=_dumps(data_dict), headers=headers
         )
 
         return self._process_response(res, [201])
@@ -212,9 +208,7 @@ class PipelineWorkflowMixin:
             }
         )
 
-        res = self._perform_request(
-            "put", url, data=json.dumps(data_dict), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(data_dict), headers=headers)
 
         return self._process_response(res, [200])
 
@@ -280,7 +274,7 @@ class PipelineWorkflowMixin:
         )
 
         res = self._perform_request(
-            "put", url, data=json.dumps({"after": after}), headers=headers
+            "put", url, data=_dumps({"after": after}), headers=headers
         )
 
         return self._process_response(res, [202])
@@ -315,6 +309,7 @@ class PipelineWorkflowMixin:
         step_ids: Optional[Union[str, List[str]]] = None,
         run_linked_steps: Optional[bool] = None,
         query: Optional[str] = None,
+        include_sub_items: Optional[bool] = None,
     ):
         """Rerun a pipeline workflow using the data of its configured data sources.
 
@@ -334,6 +329,12 @@ class PipelineWorkflowMixin:
             only with the rerun from index, in order to rerun only the items returned by
             the query.
             [1] https://go.squirro.com/query-syntax
+        :param include_sub_items: if set to True, then the sub-items of the items will
+            also be fetched and included in the rerun data. If set to False, then no
+            sub-items will be fetched. If set to None (default), then the behaviour will
+            be determined by the value of the project setting:
+            ``datasource.rerun.index.include-sub-items``.
+            This option has an effect only with the rerun from index mode.
 
         Example::
 
@@ -362,6 +363,8 @@ class PipelineWorkflowMixin:
             data["run_linked_steps"] = run_linked_steps
         if query:
             data["query"] = query
+        if include_sub_items is not None:
+            data["include_sub_items"] = include_sub_items
 
         url = (
             "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
@@ -375,7 +378,55 @@ class PipelineWorkflowMixin:
         )
 
         res = self._perform_request(
-            "post", url, params=params, data=json.dumps(data), headers=headers
+            "post", url, params=params, data=_dumps(data), headers=headers
         )
 
         return self._process_response(res)
+
+    def add_model_to_pipeline_workflow(
+        self, project_id, workflow_id, model_id, document_label=None
+    ):
+        """Updates a pipeline workflow with a published model from AI Studio.
+
+        :param project_id: project id
+        :param workflow_id: pipeline workflow id
+        :param model_id: id of published model in AI Studio
+        :param document_label: (required only for document-level classifiers) **name** (not display name) of the label that the model should use to classify documents (the label must exist).
+
+        Example::
+
+            >>> client.add_model_to_pipeline_workflow(
+            >>>     project_id='project_id_1',
+            >>>     workflow_id='pipeline_workflow_id_1',
+            >>>     model_id="model_id_1",
+            >>>     document_label="ml_classification")
+        """
+        headers = {"Content-Type": "application/json"}
+        url = "{ep}/v0/{tenant}/projects/{project_id}/pipeline_sections".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
+
+        res = self._perform_request("get", url, headers=headers)
+
+        data = {"pipeline_sections": res.json()}
+
+        if document_label is not None:
+            data["document_label"] = document_label
+
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "pipeline_workflows/%(workflow_id)s/model/%(model_id)s"
+            % {
+                "ep": self.topic_api_url,
+                "tenant": self.tenant,
+                "project_id": project_id,
+                "workflow_id": workflow_id,
+                "model_id": model_id,
+            }
+        )
+
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
+
+        return self._process_response(res, [204])
