@@ -1,13 +1,13 @@
 import base64
-import json
 import logging
 import re
 
+from ..util import _dumps
+
 log = logging.getLogger(__name__)
 
 
 class ProjectsMixin:
-
     PROJECT_ATTRIBUTES = {
         "default_search",
         "title",
@@ -20,6 +20,7 @@ class ProjectsMixin:
         "first_visit",
         "newsletter_config",
         "photo",
+        "project_type",
     }
 
     def get_user_projects(self):
@@ -38,7 +39,9 @@ class ProjectsMixin:
         """
 
         url = "{ep}/{version}/{tenant}/projects".format(
-            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
 
         res = self._perform_request("get", url)
@@ -78,6 +81,7 @@ class ProjectsMixin:
         default_sort=None,
         project_id=None,
         photo=None,
+        project_type=None,
     ):
         """Create a new project.
 
@@ -99,6 +103,8 @@ class ProjectsMixin:
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
         :param photo: Address to the photo of the project
+        :param project_type: Optional string parameter (`normal`, `monitoring`) to
+            define the type for the project.
         :returns: A dictionary which contains the project identifier.
 
         Example::
@@ -111,12 +117,15 @@ class ProjectsMixin:
                     locator=locator,
                     default_sort=default_sort,
                     photo='https://twitter.com/Cristiano/photo',
+                    project_type='normal',
                 )
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
         url = "{ep}/{version}/{tenant}/projects".format(
-            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
 
         # build data
@@ -128,11 +137,13 @@ class ProjectsMixin:
         if owner_id is not None:
             data["owner_id"] = owner_id
         if locator is not None:
-            data["locator"] = json.dumps(locator)
+            data["locator"] = _dumps(locator)
         if default_sort is not None:
-            data["default_sort"] = json.dumps(default_sort)
+            data["default_sort"] = _dumps(default_sort)
         if photo is not None:
             data["photo"] = photo
+        if project_type is not None:
+            data["project_type"] = project_type
 
         res = self._perform_request("post", url, data=data)
         return self._process_response(res, [201])
@@ -146,6 +157,7 @@ class ProjectsMixin:
         template_path=None,
         project_id=None,
         keep_ids=False,
+        project_type=None,
         import_app_nav_bar=True,
         import_default_sort=True,
         import_dashboards=True,
@@ -196,6 +208,8 @@ class ProjectsMixin:
             project with the provided id. The length of the parameter must
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
+        :param project_type: Optional string parameter (`normal`, `monitoring`) to
+            define the type for the project.
         :param import_app_nav_bar: Boolean. Whether to include the
             app & nav bar. Defaults to `True`.
         :param import_default_sort: Boolean. Whether to include the
@@ -260,13 +274,18 @@ class ProjectsMixin:
 
         Example::
 
-            >>> client.new_project_from_template('My Project',
-                                                 template_name="My Template")
+            >>> client.new_project_from_template(
+                    'My Project',
+                    template_name='My Template',
+                    project_type='normal',
+                )
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
         url = "{ep}/{version}/{tenant}/projects_from_template".format(
-            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
 
         # build data
@@ -280,11 +299,13 @@ class ProjectsMixin:
         if project_id is not None:
             data["project_id"] = project_id
         if locator is not None:
-            data["locator"] = json.dumps(locator)
+            data["locator"] = _dumps(locator)
         if keep_ids:
             # Even though eventually keep_ids will end up as part of import_options,
             # let's keep the separation for the user's convenience
             data["keep_ids"] = True
+        if project_type is not None:
+            data["project_type"] = project_type
 
         import_options = {
             "import_app_nav_bar": import_app_nav_bar,
@@ -314,7 +335,7 @@ class ProjectsMixin:
             "import_guide_file": import_guide_file,
             "import_ais_published_models": import_ais_published_models,
         }
-        data["import_options"] = json.dumps(import_options)
+        data["import_options"] = _dumps(import_options)
 
         data["token"] = self.refresh_token
 
@@ -332,8 +353,11 @@ class ProjectsMixin:
 
         Example::
 
-            >>> client.modify_project('gd9eIipOQ-KobU0SwJ8VcQ',
-            ...                       title='My Other Project')
+            >>> client.modify_project(
+                    'gd9eIipOQ-KobU0SwJ8VcQ',
+                    title='My Other Project',
+                    project_type='normal',
+                )
 
         """
         url = "{ep}/{version}/{tenant}/projects/{project_id}".format(
@@ -350,7 +374,7 @@ class ProjectsMixin:
                 data[key] = kwargs[key]
 
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201, 204])
 
     def delete_project(self, project_id):
@@ -423,9 +447,7 @@ class ProjectsMixin:
         data = {k: v for k, v in args.items() if v is not None}
 
         if data:
-            res = self._perform_request(
-                "post", url, data=json.dumps(data), headers=headers
-            )
+            res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         else:
             res = {}
         self._process_response(res, [200])
@@ -550,7 +572,7 @@ class ProjectsMixin:
             defaults to `False`. Needs the `export_facets` to be True.
         :param export_items_config: Dict. Containing the query parameters that
             can be used to filter down the exported items. Currently only
-            `query` and `count` parameters are supported.
+            `query`, `count` and `fields` parameters are supported.
         :param export_ais_published_models: Boolean. Whether to include
             the published ml models, defaults to `True`.
         :return: Returns a dictionary containing the API response data and
@@ -607,7 +629,7 @@ class ProjectsMixin:
 
         data = {k: v for k, v in export_options.items() if v is not None}
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
 
         if res.status_code != 201:
             res.raise_for_status()
@@ -699,7 +721,6 @@ class ProjectsMixin:
         import_guide_file=True,
         import_ais_published_models=True,
     ):
-
         """Imports parts or all configuration and metadata of a project.
 
         The following entities can be imported:
@@ -841,7 +862,7 @@ class ProjectsMixin:
         with open(project_archive, "rb") as f:
             data["archive"] = base64.b64encode(f.read()).decode("utf-8")
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
 
         if res.status_code != 201:
             res.raise_for_status()
