@@ -1,9 +1,8 @@
-import json
-
 from ..exceptions import InputDataError
+from ..util import _dumps
 
 
-class SavedSearchesMixin(object):
+class SavedSearchesMixin:
     def new_savedsearch(
         self,
         scope_type,
@@ -19,8 +18,8 @@ class SavedSearchesMixin(object):
     ):
         """Create a new saved search.
 
-        :param scope_type: Saved search scope type.
-        :param scope_id: Project identifier.
+        :param scope_type: Saved search scope type (:code:`"project"` or :code:`"user"`).
+        :param scope_id: Identifier of the associated scope (the effective project_id or user_id)
         :param query: Saved search query.
         :param name: The name of the new saved search.
         :param actions: A list of actions to execute when the saved search
@@ -65,7 +64,7 @@ class SavedSearchesMixin(object):
             "relative_end": relative_end,
             "dashboard_id": dashboard_id,
         }
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201, 200])
 
     def modify_savedsearch(
@@ -84,8 +83,8 @@ class SavedSearchesMixin(object):
         """Modify a saved search.
 
         :param savedsearch_id: Saved search identifier.
-        :param scope_type: Saved search scope type.
-        :param scope_id: Project identifier.
+        :param scope_type: Saved search scope type (:code:`"project"` or :code:`"user"`).
+        :param scope_id: Identifier of the associated scope (the effective project_id or user_id)
         :param query: Saved search query.
         :param name: The new name of the saved search.
         :param actions: A list of actions to execute when the saved search
@@ -127,14 +126,14 @@ class SavedSearchesMixin(object):
             "relative_end": relative_end,
         }
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def get_savedsearches(self, scope_type, scope_id):
         """Get saved searches for the provided scope.
 
-        :param scope_type: Saved search scope type.
-        :param scope_id: Project identifier.
+        :param scope_type: Saved search scope type (:code:`"project"` or :code:`"user"`).
+        :param scope_id: Identifier of the associated scope (the effective project_id or user_id)
         :returns: A dictionary with data for the saved searches.
 
         Example::
@@ -164,8 +163,8 @@ class SavedSearchesMixin(object):
     def get_savedsearch(self, scope_type, scope_id, savedsearch_id):
         """Get saved search details.
 
-        :param scope_type: Saved search scope type.
-        :param scope_id: Project identifier.
+        :param scope_type: Saved search scope type (:code:`"project"` or :code:`"user"`).
+        :param scope_id: Identifier of the associated scope (the effective project_id or user_id)
         :param savedsearch_id: Saved search identifier.
         :returns: A dictionary with saved search data.
 
@@ -197,8 +196,8 @@ class SavedSearchesMixin(object):
     def delete_savedsearch(self, scope_type, scope_id, savedsearch_id):
         """Delete a savedsearch.
 
-        :param scope_type: Saved search scope type.
-        :param scope_id: Project identifier.
+        :param scope_type: Saved search scope type (:code:`"project"` or :code:`"user"`).
+        :param scope_id: Identifier of the associated scope (the effective project_id or user_id)
         :param savedsearch_id: Saved search identifier.
 
         Example::
