@@ -1,6 +1,7 @@
-import json
 import logging
 
+from ..util import _dumps
+
 log = logging.getLogger(__name__)
 
 
@@ -19,6 +20,6 @@ class SmartAnswersMixin:
             "/smart_answers/similar_searches"
         )
         headers = {"Content-Type": "application/json"}
-        params = {"query": query, "options": json.dumps(options)}
+        params = {"query": query, "options": _dumps(options)}
         res = self._perform_request("get", url, headers=headers, params=params)
         return self._process_response(res)["result"]
