@@ -1,7 +1,6 @@
-import json
 from typing import Optional
 
-from squirro_client.util import _clean_params, deprecation
+from ..util import _clean_params, _dumps, deprecation
 
 
 class SourcesMixin:
@@ -399,7 +398,7 @@ class SourcesMixin:
         if priority is not None:
             data["priority"] = priority
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [200, 201])
 
     def modify_source(
@@ -503,7 +502,7 @@ class SourcesMixin:
         if priority is not None:
             data["priority"] = priority
 
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [200])
 
     def delete_source(self, project_id, source_id):
@@ -715,6 +714,55 @@ class SourcesMixin:
         res = self._perform_request("put", url, params=params)
         self._process_response(res, [200, 204])
 
+    def retry_failed_batches(
+        self,
+        project_id: str,
+        source_id: str,
+        batch_id: Optional[str] = None,
+        batch_priority: Optional[str] = None,
+    ):
+        """Move all the failed batches of a given source back for processing.
+
+        If batch identifier will be specified, only this specific batch will be moved.
+
+        If batch priority level will be specified, only batches with this priority level
+        will be moved.
+
+        :param project_id: project identifier
+        :param source_id: source identifier
+        :param batch_id: optional batch identifier
+        :param batch_priority: optional batch priority level
+
+        :return: tuple with number of moved batches and items
+
+        Example:
+
+            >>> client.retry_failed_batches(
+            ...     "Oqc-DYVWRGe9gtDYBIiKyA",
+            ...     "uu6nikJZTiWazZJ0-iOXKA",
+            ...     batch_id="1zxAeuo1Syyi5zgZgihwkg",
+            ...     batch_priority="high")
+        """
+        url = "%(ep)s/%(version)s/ingester/projects/%(project_id)s/sources/%(source_id)s/retry"
+        url = url % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+
+        data = {}
+        if batch_id:
+            data["batch_id"] = batch_id
+        if batch_priority:
+            data["batch_priority"] = batch_priority
+
+        headers = {"Content-Type": "applicaton/json"}
+
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
+
+        return self._process_response(res, [200, 204])
+
     def get_max_inc(self, project_id, source_id):
         """Fetches the maximum incremental value of a source.
 
@@ -772,11 +820,10 @@ class SourcesMixin:
             "source_id": source_id,
         }
         data = {"data": {"max_inc_value": max_inc_value}}
-        res = self._perform_request("put", url, data=json.dumps(data))
+        res = self._perform_request("put", url, data=_dumps(data))
         self._process_response(res, [200, 204])
 
     def get_preview(self, project_id, config):
-
         """Preview the source configuration.
 
         :param project_id: Project identifier.
@@ -827,7 +874,7 @@ class SourcesMixin:
         }
 
         # build params
-        params = {"config": json.dumps(config)}
+        params = {"config": _dumps(config)}
 
         res = self._perform_request("get", url, params=params)
         return self._process_response(res)
