@@ -4,7 +4,7 @@
 from ..util import deprecation
 
 
-class SubscriptionsMixin(object):
+class SubscriptionsMixin:
     def get_object_subscriptions(
         self, project_id, object_id, user_id=None, filter_deleted=None
     ):
@@ -39,7 +39,7 @@ class SubscriptionsMixin(object):
                     u'source_id': u'2VkLodDHTmiMO3rlWi2MVQ',
                     u'title': u'News Alerts for "squirro" in Switzerland',
                     u'workflow': {
-                        u'name': u'Default Workflow',
+                        u'name': u'Standard',
                         u'project_default': True,
                         u'id': u'kAvdogQOQvGHijqcIPi_WA',
                         u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
@@ -86,7 +86,7 @@ class SubscriptionsMixin(object):
                 u'processed': True,
                 u'paused': False,
                 u'workflow': {
-                    u'name': u'Default Workflow',
+                    u'name': u'Standard',
                     u'project_default': True,
                     u'id': u'kAvdogQOQvGHijqcIPi_WA',
                     u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
@@ -152,7 +152,7 @@ class SubscriptionsMixin(object):
              u'processed': False,
              u'paused': False,
              u'workflow': {
-                u'name': u'Default Workflow',
+                u'name': u'Standard',
                 u'project_default': True,
                 u'id': u'kAvdogQOQvGHijqcIPi_WA',
                 u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'}
