@@ -1,10 +1,9 @@
-import json
 from datetime import datetime, timedelta
 
-from ..util import deprecation
+from ..util import _dumps, deprecation
 
 
-class TrendDetectionMixin(object):
+class TrendDetectionMixin:
     def new_trenddetection(
         self,
         project_id,
@@ -87,7 +86,7 @@ class TrendDetectionMixin(object):
         }
 
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def modify_trenddetection(self, project_id, trenddetection_id, **kwargs):
@@ -108,7 +107,7 @@ class TrendDetectionMixin(object):
         """
 
         # Get rid of `None` parameters
-        params = dict([(k, v) for k, v in kwargs.items() if v is not None])
+        params = {k: v for k, v in kwargs.items() if v is not None}
 
         url = self._get_trenddetection_base_url(trenddetection_id) % {
             "ep": self.topic_api_url,
@@ -117,9 +116,7 @@ class TrendDetectionMixin(object):
             "trenddetection_id": trenddetection_id,
         }
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
-        res = self._perform_request(
-            "put", url, data=json.dumps(params), headers=headers
-        )
+        res = self._perform_request("put", url, data=_dumps(params), headers=headers)
         return self._process_response(res, [204])
 
     def get_trenddetections(self, project_id):
@@ -241,7 +238,7 @@ class TrendDetectionMixin(object):
             "result_before": result_before,
         }
 
-        params = dict([(k, v) for k, v in params.items() if v is not None])
+        params = {k: v for k, v in params.items() if v is not None}
 
         headers = {"Accept": "application/json"}
         res = self._perform_request("get", url, params=params, headers=headers)
@@ -400,7 +397,6 @@ class TrendDetectionMixin(object):
         # get first & last timestamp of thresholds data, in order to filter the
         # historical data with the same time stamps
         if include_historical_data:
-
             # return empty historical data if we get back no thresholds data
             if len(ret["thresholds"]) < 2:
                 ret["historical_values"] = {"values": []}
@@ -483,7 +479,7 @@ class TrendDetectionMixin(object):
         return ret
 
     def _get_trenddetection_base_url(self, trenddetection_id=None):
-        """Returns the URL template for a trend detection. """
+        """Returns the URL template for a trend detection."""
         parts = ["%(ep)s/v0/%(tenant)s"]
         parts.append("/projects/%(project_id)s/trenddetections")
 
