@@ -1,15 +1,16 @@
 import base64
 import io
-import json
 import os
-import tarfile
 import uuid
+from tarfile import TarInfo
 
 import hjson
+import tarsafe
+
+from ..util import _dumps
 
 
-class WidgetsAndAssetsMixin(object):
-
+class WidgetsAndAssetsMixin:
     #
     # Dashboard Custom Widgets
     #
@@ -29,10 +30,10 @@ class WidgetsAndAssetsMixin(object):
                                u'titleColor': u'#525252',
                                .....}]}]
         """
-        url = "%(ep)s/v0/%(tenant)s/widgets" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/v0/{tenant}/widgets".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -55,11 +56,11 @@ class WidgetsAndAssetsMixin(object):
                              u'titleColor': u'#525252',
                              .....}]}]
         """
-        url = "%(ep)s/v0/%(tenant)s/widgets/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/widgets/{name}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            name=name,
+        )
 
         params = {}
         if include_files:
@@ -112,7 +113,7 @@ class WidgetsAndAssetsMixin(object):
 
         try:
             with io.BytesIO() as binary_data:
-                with tarfile.open(fileobj=binary_data, mode="w|gz") as tar:
+                with tarsafe.open(fileobj=binary_data, mode="w|gz") as tar:
                     tar.add(
                         directory,
                         arcname=name,
@@ -128,7 +129,7 @@ class WidgetsAndAssetsMixin(object):
                     # for widget config use innermost_directory/widget.ini for
                     # tar which is relative to innermost_directory
                     relative_widget_ini = name + "/" + "widget.ini"
-                    tarinfo = tarfile.TarInfo(relative_widget_ini)
+                    tarinfo = TarInfo(relative_widget_ini)
                     tarinfo.size = len(data)
                     tar.addfile(tarinfo, widget_config)
 
@@ -137,13 +138,13 @@ class WidgetsAndAssetsMixin(object):
             raise ValueError(e)
 
         headers = {"Content-Type": "application/json"}
-        url = "%(ep)s/v0/%(tenant)s/widgets/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/widgets/{name}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            name=name,
+        )
         res = self._perform_request(
-            "post", url, data=json.dumps(data_dict), headers=headers
+            "post", url, data=_dumps(data_dict), headers=headers
         )
         return self._process_response(res, [201])
 
@@ -156,11 +157,11 @@ class WidgetsAndAssetsMixin(object):
 
             >>> client.delete_dashboard_widget('custom_widget')
         """
-        url = "%(ep)s/v0/%(tenant)s/widgets/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/widgets/{name}".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            name=name,
+        )
         res = self._perform_request("delete", url)
         self._process_response(res, [204])
 
@@ -185,11 +186,11 @@ class WidgetsAndAssetsMixin(object):
                                u'titleColor': u'#525252',
                                .....}]}]
         """
-        url = "%(ep)s/v0/%(tenant)s/assets/%(asset_type)s" % {
-            "ep": self.topic_api_url,
-            "tenant": "_global" if global_assets else self.tenant,
-            "asset_type": asset_type,
-        }
+        url = "{ep}/v0/{tenant}/assets/{asset_type}".format(
+            ep=self.topic_api_url,
+            tenant="_global" if global_assets else self.tenant,
+            asset_type=asset_type,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -214,12 +215,12 @@ class WidgetsAndAssetsMixin(object):
                              u'titleColor': u'#525252',
                              .....}]}]
         """
-        url = "%(ep)s/v0/%(tenant)s/assets/%(asset_type)s/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": "_global" if global_asset else self.tenant,
-            "asset_type": asset_type,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/assets/{asset_type}/{name}".format(
+            ep=self.topic_api_url,
+            tenant="_global" if global_asset else self.tenant,
+            asset_type=asset_type,
+            name=name,
+        )
 
         params = {}
         if include_files:
@@ -239,12 +240,12 @@ class WidgetsAndAssetsMixin(object):
 
             >>> client.delete_asset('dashboard_loader', 'layer_loader')
         """
-        url = "%(ep)s/v0/%(tenant)s/assets/%(asset_type)s/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": "_global" if global_asset else self.tenant,
-            "asset_type": asset_type,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/assets/{asset_type}/{name}".format(
+            ep=self.topic_api_url,
+            tenant="_global" if global_asset else self.tenant,
+            asset_type=asset_type,
+            name=name,
+        )
         res = self._perform_request("delete", url)
         self._process_response(res, [204])
 
@@ -279,7 +280,7 @@ class WidgetsAndAssetsMixin(object):
         asset_json = os.path.join(folder, asset_type + ".json")
 
         if os.path.exists(asset_json):
-            with open(asset_json, "r") as asset_config:
+            with open(asset_json) as asset_config:
                 config = hjson.load(fp=asset_config)
 
         if "hash" in config:
@@ -287,18 +288,18 @@ class WidgetsAndAssetsMixin(object):
 
         config["hash"] = str(uuid.uuid1())
 
-        url = "%(ep)s/v0/%(tenant)s/assets/%(asset_type)s/%(name)s" % {
-            "ep": self.topic_api_url,
-            "tenant": "_global" if global_asset else self.tenant,
-            "asset_type": asset_type,
-            "name": name,
-        }
+        url = "{ep}/v0/{tenant}/assets/{asset_type}/{name}".format(
+            ep=self.topic_api_url,
+            tenant="_global" if global_asset else self.tenant,
+            asset_type=asset_type,
+            name=name,
+        )
 
         # Send the data as base64. For unknown reasons sending the file
         # natively via python's requests.files did not work.
         try:
             binary_data = io.BytesIO()
-            with tarfile.open(fileobj=binary_data, mode="w|gz") as tar:
+            with tarsafe.open(fileobj=binary_data, mode="w|gz") as tar:
                 tar.add(folder, arcname=name, recursive=True)
 
             tar_gz_base64 = base64.b64encode(binary_data.getvalue())
@@ -306,7 +307,7 @@ class WidgetsAndAssetsMixin(object):
             raise ValueError(e)
 
         res = self._perform_request(
-            "post", url, data={"config": json.dumps(config), "data": tar_gz_base64}
+            "post", url, data={"config": _dumps(config), "data": tar_gz_base64}
         )
 
         return self._process_response(res, [201])
