@@ -1,6 +1,7 @@
-import json
 import re
 
+from .util import _dumps, deprecation
+
 
 class UserApiMixin:
     """Mixin class which encapsulates the functionality of the user API
@@ -65,7 +66,7 @@ class UserApiMixin:
         if api_version == "v1":
             headers = {"Content-Type": "application/json"}
             res = self._perform_request(
-                "put", url, data=json.dumps(changes), headers=headers
+                "put", url, data=_dumps(changes), headers=headers
             )
 
         else:
@@ -103,7 +104,7 @@ class UserApiMixin:
             "new_password_confirm": new_password_confirm,
         }
 
-        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=_dumps(data), headers=headers)
         return self._process_response(res)
 
     def get_users_password_policy(self):
@@ -215,7 +216,7 @@ class UserApiMixin:
         headers = {"Content-Type": "application/json"}
 
         res = self._perform_request(
-            "post", url, params=params, data=json.dumps(data), headers=headers
+            "post", url, params=params, data=_dumps(data), headers=headers
         )
         return self._process_response(res, [200, 201])
 
@@ -330,6 +331,30 @@ class UserApiMixin:
         res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
 
+    def get_session(self, user_id, session_id):
+        """Get data of a specific session.
+
+        :param user_id: User identifier.
+        :param session_id: Session identifier
+
+        Example::
+
+            >>> client.get_session('H5Qv-WhgSBGW0WL8xolSCQ', 'yL0dnd17RNe9Jpn7uAa8Bw')
+        """
+
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s" "/users/%(user)s/sessions/%(session_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user": user_id,
+            "session_id": session_id,
+        }
+
+        res = self._perform_request("get", url)
+        return self._process_response(res, [200])
+
     def delete_session(self, user_id, session_id):
         """Delete a session.
 
@@ -411,7 +436,7 @@ class UserApiMixin:
 
         url = f"{self.user_api_url}/v0/{self.tenant}/users"
 
-        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=_dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def delete_user(self, user_id):
@@ -490,9 +515,32 @@ class UserApiMixin:
             }
         """
 
-        url = ("%(ep)s/msexchange/oauth2_token") % {"ep": self.user_api_url}
-        params = {}
-        params["msexchuid"] = msexchuid
+        msg = (
+            "The `get_token_from_msexchuid` method is obsolete. It has been replaced by"
+            " the `get_token_from_msexchuid_token` method."
+        )
+        deprecation(msg)
+        raise NotImplementedError(msg)
+
+    def get_token_from_msexchuid_token(self, msexchuid_token):
+        """
+        Retrieves an OAUTH2 authentication token based on the provided MS Exchange user
+        identity token.
+
+        :param msexchuid_token: a Microsoft Exchange user identity token (JWT).
+        :return: A dictionary containing the OAUTH2 token and the Squirro user id.
+
+        Example::
+
+            >>> client.get_token_from_msexchuid_token("<your.jwt.token>")
+            {
+                u'oauth2_token': u'5ad37930dda85a7...6c066b2253dba8d19',
+                u'user_id': u'vP7h4g7EThuJKIfMorHTUQ',
+            }
+        """
+        url = f"{self.user_api_url}/msexchange/oauth2_token"
+
+        params = {"msexchuid_token": msexchuid_token}
 
         res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
