@@ -40,11 +40,18 @@ try:
 except ImportError:
     import json as _json
 
+    def _loads(s: Union[str, bytes]) -> Any:
+        return _json.loads(s)
+
     def _dumps(obj) -> str:
         return _json.dumps(obj, default=_json_default)
 
 else:
 
+    def _loads(s: Union[str, bytes]) -> Any:
+        """Speedier JSON deserialization."""
+        return orjson.loads(s)
+
     def _dumps(obj) -> bytes:
         """Speedier JSON serialization."""
         return orjson.dumps(
@@ -54,4 +61,5 @@ else:
         )
 
 
+_loads: Callable[[Union[str, bytes]], Any]
 _dumps: Callable[[Any], Union[str, bytes]]
